Learn R Programming

DynNom (version 4.0)

DNbuilder.glm: Shiny code for Dynamic Nomograms

Description

DNbuilder.glm provides required scripts to deploy an lm model object as a dynamic nomogram on a server on the web such as the http://shinyapps.io.

Usage

DNbuilder.glm(model, data, clevel = 0.95, covariate = c("slider", "numeric"))

Arguments

model
a glm model object
data
dataframe containing the accompanying data
clevel
confidence level required
covariate
The option to choose the type of covariate(s) input control widget for numeric values. If "slider" (the default) is chosen a shiny application with slider control widgets are used while if "numeric" is chosen numeric values input controls will be displayed.

Value

A new folder in the current working directory called DynNomapp which contains all the required scripts to deploy this dynamic nomogram on a server on the web such as the http://shinyapps.io. This folder includes ui.R, server.R and global.R script files needed to build the application and dataset.rds which is the accompanying dataset and a user guide text file called README.txt which explains how to deploy the app using all these objects.

See Also

glm, DynNom, DynNom.glm

Examples

Run this code
## Not run: 
# # a generilized linear model
# model1 <- glm(Fertility ~ Agriculture + Education + Catholic, data = swiss)
# DNbuilder.glm(model1, swiss, clevel = 0.9)
# 
# # a logistic regression model
# data1 =as.data.frame(Titanic)
# model2 <- glm(Survived ~ Age + Class + Sex, data = data1, weights = Freq,
#               family = binomial("probit"))
# DNbuilder(model2, as.data.frame(Titanic), clevel = 0.9)
# ## End(Not run)

if (interactive()) {
# a poisson regression model
model3 <- glm(event ~ mag + dist + accel, data = attenu, family = poisson)
DNbuilder(model3, attenu, covariate = "numeric")
}

Run the code above in your browser using DataLab